# pylint: disable=C0103
"""Migration file"""

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    """Migration file"""

    dependencies = [
        ("netbox_docker_plugin", "0031_container_cap_add"),
    ]

    operations = [
        migrations.RunSQL(
            """
CREATE TABLE IF NOT EXISTS public.netbox_docker_plugin_device
(
    id bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    host_path character varying(1024) NOT NULL,
    container_path character varying(1024) NOT NULL,
    container_id bigint NOT NULL,
    CONSTRAINT netbox_docker_plugin_device_pkey PRIMARY KEY (id),
    CONSTRAINT netbox_docker_plugin_device_unique_device UNIQUE
        (container_id, container_path, host_path),
    CONSTRAINT netbox_docker_plugin_container_id_a53ca874_fk_netbox_do FOREIGN KEY (container_id)
        REFERENCES public.netbox_docker_plugin_container (id) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
        DEFERRABLE INITIALLY DEFERRED
);
CREATE INDEX IF NOT EXISTS netbox_docker_plugin_device_container_id_a53ca874
    ON public.netbox_docker_plugin_device USING btree
    (container_id ASC NULLS LAST);
            """,
            state_operations=
            [
                migrations.CreateModel(
                    name="Device",
                    fields=[
                        (
                            "id",
                            models.BigAutoField(
                                auto_created=True, primary_key=True, serialize=False
                            ),
                        ),
                        (
                            "host_path",
                            models.CharField(
                                max_length=1024,
                                validators=[
                                    django.core.validators.MinLengthValidator(
                                        limit_value=1
                                    ),
                                    django.core.validators.MaxLengthValidator(
                                        limit_value=1024
                                    ),
                                ],
                            ),
                        ),
                        (
                            "container_path",
                            models.CharField(
                                max_length=1024,
                                validators=[
                                    django.core.validators.MinLengthValidator(
                                        limit_value=1
                                    ),
                                    django.core.validators.MaxLengthValidator(
                                        limit_value=1024
                                    ),
                                ],
                            ),
                        ),
                        (
                            "container",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="devices",
                                to="netbox_docker_plugin.container",
                            ),
                        ),
                    ],
                    options={
                        "ordering": ("container", "container_path", "host_path"),
                    },
                ),
                migrations.AddConstraint(
                    model_name="device",
                    constraint=models.UniqueConstraint(
                        fields=("container", "container_path", "host_path"),
                        name="netbox_docker_plugin_device_unique_device",
                    ),
                ),
            ],
        ),
    ]
